==> trilinos_12.18.1.orig.tar.gz: Trilinos-trilinos-release-12-18-1/packages/phalanx/test/AssemblyHeatFluxFad/evaluators/Evaluator_Density.hpp <==
// @HEADER
// ************************************************************************
//
//        Phalanx: A Partial Differential Equation Field Evaluation 
//       Kernel for Flexible Management of Complex Dependency Chains
//                    Copyright 2008 Sandia Corporation
//
// Under terms of Contract DE-AC04-94AL85000, there is a non-exclusive
// license for use of this work by or on behalf of the U.S. Government.
//
// Redistribution and use in source and binary forms, with or without
// modification, are permitted provided that the following conditions are
// met:
//
// 1. Redistributions of source code must retain the above copyright
// notice, this list of conditions and the following disclaimer.
//
// 2. Redistributions in binary form must reproduce the above copyright
// notice, this list of conditions and the following disclaimer in the
// documentation and/or other materials provided with the distribution.
//
// 3. Neither the name of the Corporation nor the names of the
// contributors may be used to endorse or promote products derived from
// this software without specific prior written permission.
//
// THIS SOFTWARE IS PROVIDED BY SANDIA CORPORATION "AS IS" AND ANY
// EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
// IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR
// PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL SANDIA CORPORATION OR THE
// CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL,
// EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
// PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR
// PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF
// LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING
// NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS
// SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
//
// Questions? Contact Roger Pawlowski (rppawlo@sandia.gov), Sandia
// National Laboratories.
//
// ************************************************************************
// @HEADER


#ifndef PHX_EXAMPLE_VP_DENSITY_HPP
#define PHX_EXAMPLE_VP_DENSITY_HPP

#include "Phalanx_config.hpp"
#ifdef  PHX_ENABLE_KOKKOS_AMT
#include "Phalanx_Evaluator_TaskBase.hpp"
#else
#include "Phalanx_Evaluator_WithBaseImpl.hpp"
#endif
#include "Phalanx_Evaluator_Derived.hpp"
#include "Phalanx_MDField.hpp"

//struct DensityTag {};

template<typename EvalT, typename Traits>
class Density :
#ifdef PHX_ENABLE_KOKKOS_AMT
  public PHX::TaskBase<Traits,Density<EvalT,Traits>>,
#else
  public PHX::EvaluatorWithBaseImpl<Traits>,
#endif 
  public PHX::EvaluatorDerived<EvalT, Traits> {
  
public:
  
  Density(const Teuchos::ParameterList& p);
  
  void postRegistrationSetup(typename Traits::SetupData d,
			     PHX::FieldManager<Traits>& vm);
  
  void evaluateFields(typename Traits::EvalData ud);

  KOKKOS_INLINE_FUNCTION
    void operator () (const int i) const;  

  // KOKKOS_INLINE_FUNCTION
  //   void operator () (const DensityTag, const int i) const;  

  // KOKKOS_INLINE_FUNCTION
  //   void operator () (const DensityTag, typename Kokkos::TeamPolicy<>::member_type & team) const;  
  
private:
  
  typedef typename EvalT::ScalarT ScalarT;

  double constant;

  PHX::MDField<ScalarT,Cell,Point> density;
  PHX::MDField<const ScalarT,Cell,Point> temp;

  std::size_t cell_data_size;

};

#include "Evaluator_Density_Def.hpp"

#endif

==> trilinos_16.1.0.orig.tar.gz: Trilinos-trilinos-release-16-1-0/packages/phalanx/test/AssemblyHeatFluxFad/evaluators/Evaluator_Density.hpp <==
// @HEADER
// *****************************************************************************
//        Phalanx: A Partial Differential Equation Field Evaluation 
//       Kernel for Flexible Management of Complex Dependency Chains
//
// Copyright 2008 NTESS and the Phalanx contributors.
// SPDX-License-Identifier: BSD-3-Clause
// *****************************************************************************
// @HEADER

#ifndef PHX_EXAMPLE_VP_DENSITY_HPP
#define PHX_EXAMPLE_VP_DENSITY_HPP

#include "Phalanx_config.hpp"
#ifdef  PHX_ENABLE_KOKKOS_AMT
#include "Phalanx_Evaluator_TaskBase.hpp"
#else
#include "Phalanx_Evaluator_WithBaseImpl.hpp"
#endif
#include "Phalanx_Evaluator_Derived.hpp"
#include "Phalanx_MDField.hpp"

//struct DensityTag {};

template<typename EvalT, typename Traits>
class Density :
#ifdef PHX_ENABLE_KOKKOS_AMT
  public PHX::TaskBase<Traits,Density<EvalT,Traits>>,
#else
  public PHX::EvaluatorWithBaseImpl<Traits>,
#endif
  public PHX::EvaluatorDerived<EvalT, Traits> {

public:

  Density(const Teuchos::ParameterList& p);

  void postRegistrationSetup(typename Traits::SetupData d,
			     PHX::FieldManager<Traits>& vm);

  void evaluateFields(typename Traits::EvalData ud);

  KOKKOS_INLINE_FUNCTION
    void operator () (const int i) const;

  // KOKKOS_INLINE_FUNCTION
  //   void operator () (const DensityTag, const int i) const;

  // KOKKOS_INLINE_FUNCTION
  //   void operator () (const DensityTag, typename Kokkos::TeamPolicy<>::member_type & team) const;

private:

  typedef typename EvalT::ScalarT ScalarT;

  double constant;

  PHX::MDField<ScalarT,Cell,Point> density;

  // Should normally use a const dependent field. We will use a
  // non-const to test the method addNonConstDependentField.
  // PHX::MDField<const ScalarT,Cell,Point> temp;
  PHX::MDField<ScalarT,Cell,Point> temp;

  std::size_t cell_data_size;

};

#include "Evaluator_Density_Def.hpp"

#endif
